@@ -19,11 +19,11 @@ class Repository:
 
         is_debug = True if self.config.get(section='COMMANDS', key='debug') == 'True' else False
 
-        username = os.environ['MYSQL_USER'] # self.config.get(section='DATABASE', key='username')
-        password = os.environ['MYSQL_PASSWORD'] # self.config.get(section='DATABASE', key='password')
-        host = os.environ['MYSQL_HOST'] # self.config.get(section='DATABASE', key='host')
-        port = os.environ['MYSQL_PORT'] # self.config.get(section='DATABASE', key='port')
-        database = os.environ['MYSQL_DATABASE'] # self.config.get(section='DATABASE', key='database')
+        username = self.config.get(section='DATABASE', key='username')
+        password = self.config.get(section='DATABASE', key='password')
+        host = self.config.get(section='DATABASE', key='host')
+        port = self.config.get(section='DATABASE', key='port')
+        database = self.config.get(section='DATABASE', key='database')
         self.engine = create_engine(f'mysql+pymysql://{username}:{password}@{host}:{port}/{database}', echo=is_debug) # , isolation_level='READ UNCOMMITTED')
         Session = sessionmaker(bind=self.engine)
         self.session = scoped_session(Session)
