@@ -24,47 +24,46 @@ class Selenium(Scraper):
     def __init__(self, headless: bool=True, window: dict={}, user_dir: str=None):
         options = webdriver.ChromeOptions()
 
-        #region undetected_chromedriver
-        # setting profile
-        # another way to set profile is the below (which takes precedence if both variants are used
-        if user_dir is not None:
-            options.add_argument(f'--user-data-dir={user_dir}')
-        # just some options passing in to skip annoying popups
-        options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
-        #endregion undetected_chromedriver
-
         options.add_argument('--no-sandbox')
-        options.add_argument('--log-level=3')
-        options.add_argument('disable-infobars')
-        options.add_argument('--disable-extensions')
         options.add_argument('--disable-dev-shm-usage')
+        self.driver = webdriver.Remote(command_executor='http://localhost:4444/wd/hub', desired_capabilities={'browserName': 'chrome'}, options=options)
 
-        window_size = window['size'] if 'size' in window else []
+        # #region undetected_chromedriver
+        # # setting profile
+        # # another way to set profile is the below (which takes precedence if both variants are used
+        # if user_dir is not None:
+        #     options.add_argument(f'--user-data-dir={user_dir}')
+        # # just some options passing in to skip annoying popups
+        # options.add_argument('--no-first-run --no-service-autorun --password-store=basic')
+        # #endregion undetected_chromedriver
 
-        if len(window_size) == 0:
-            options.add_argument('start-maximized')
+        # options.add_argument('--no-sandbox')
+        # options.add_argument('--log-level=3')
+        # options.add_argument('disable-infobars')
+        # options.add_argument('--disable-extensions')
+        # options.add_argument('--disable-dev-shm-usage')
 
-        if headless is True:
-            options.add_argument('headless')
+        # window_size = window['size'] if 'size' in window else []
 
-        LOGGER.setLevel(logging.WARNING)
+        # if len(window_size) == 0:
+        #     options.add_argument('start-maximized')
 
-        options.add_argument('--disable-blink-features=AutomationControlled') # new
-        options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36") # new
-        # options.add_argument("user-data-dir=C:\\Users\\LCADM.G.Gargiuolo\\AppData\\Local\\Google\\Chrome\\User Data\\Default") # new
+        # if headless is True:
+        #     options.add_argument('headless')
 
-        capabilities = {'browserName': 'chrome', 'javascriptEnabled': True}
-        capabilities.update(options.to_capabilities())
-        self.driver = webdriver.Remote('http://selenium:4444/wd/hub', desired_capabilities=DesiredCapabilities.CHROME)
+        # LOGGER.setLevel(logging.WARNING)
+
+        # options.add_argument('--disable-blink-features=AutomationControlled')
+        # options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36")
 
         # if platform.system() == 'Windows':
         #     self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
         # elif platform.system() == 'Linux':
         #     self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
 
-        if len(window_size) > 0:
-            self.driver.set_window_position(x=0, y=0)
-            self.driver.set_window_size(width=window_size[0], height=window_size[1])
+        # if len(window_size) > 0:
+        #     self.driver.set_window_position(x=0, y=0)
+        #     self.driver.set_window_size(width=window_size[0], height=window_size[1])
 
         super().__init__()
 
